#include <algorithm>
#include <iostream>
#include <fstream>
#include <string>
#include <iterator>
#include <list>
#include <set>
#include <cctype>
#include <cstring>

using namespace std;

void print_diff(string& fname, set<string>& set1, set<string>& set2);
void parse_line(char* line, set<string>& results);
void parse_ips(ifstream& file, set<string>& results);

int main(int argc, char** argv) {
   string fname1 = argv[1], fname2 = argv[2];
   set<string> ips1, ips2;
   
   ifstream file1(fname1.c_str());
   parse_ips(file1, ips1);
   file1.close();
   
   ifstream file2(fname2.c_str());
   parse_ips(file2, ips2);
   file2.close();
   
   print_diff(fname1, ips1, ips2);
   print_diff(fname2, ips2, ips1);

   return 0;
}

void print_diff(string& fname, set<string>& set1, set<string>& set2) {
   list<string> diff;
   set_difference(set1.begin(), set1.end(), set2.begin(), set2.end(),
         insert_iterator< list<string> >(diff, diff.begin()));
   
   cout << "Only in " << fname;
   for (list<string>::iterator i = diff.begin(); i != diff.end(); i++) {
      cout << ' ' << *i;
   }
   cout << endl;
}

void parse_line(string& line, set<string>& results) {
   char ch;
   int octet_count = 0;
   string ip, octet;
   
   for (string::iterator i = line.begin(); i != line.end(); i++) {
      ch = *i;
      
      if (isdigit(ch)) {
         octet += ch;
      } else if (ch == '.') {
         ip += octet;
         ip += '.';
         octet_count ++;
         octet.clear();
      } else {
         if (octet_count == 3 && octet.size() > 0) {
            ip += octet;
            results.insert(ip);
            // comment out this line to parse all IPs in given line
            return;
         }
         
         octet_count = 0;
         octet.clear();
         ip.clear();
      }
   }
}

void parse_ips(ifstream& file, set<string>& results) {
   string line;
   
   while (!file.eof()) {
      getline(file, line);
      parse_line(line, results);
   }
}

